# Copyright (C) 2020 Ludvig Larsson aka Valmond ludviglarsson@protonmail.com
# This code is licensed under the terms of the GNU Public License, version 3 or later (GPL-3.0-or-later)

import os
import json

import locator

"""
This helper class loads up the configuration file and serves its data

The data is:
ip, port : our local address
LISTEN_READ_BYTES: the bytes the listener will try to read at an incoming connection
MAX_SIMULTANEOUS_CONNECTIONS: how many incoming connections do we accept simultaneously
LISTEN_TIMEOUT_SECONDS: timeout for the listener i.e it will drop client connection if nothing happens for this many seconds)
"SERVER_SEND_PACKAGE_SIZE": How big chunks the server will use to send back data, don't put it too high or you'll choke some buffers here
"MAX_STORAGE_SPACE_OTHER_MB": 1024   How many Mb we'll use to store other peoples files
"SWICHAROO_POLICY": "MAX_DOUBLE"  : How do we negociate switching one of our files versus one of another nodes files
"SWICHAROO_MINSIZE_ACCEPT_ALL" 65536 : Files under this size are always accepted in a swicharoo
"SWICHAROO_FILE_MAXSIZE_KB": 32768  : Files bigger than this are always rejected

"""


class Configuration:
    def __init__(self):
        path = 'config.json'
        if os.path.isfile(path):
            with open(os.path.join(locator.module_path(), path), 'r') as f:
                self.data = json.load(f)
        else:
            self.data = None

    def get(self, name, default=None):
        if self.data:
            if name in self.data:
                return self.data[name]
        print("#WARNING, could not find information in config file, uses default vaue, entry missing=", name)
        return default

    def data_exists(self, name):
        if self.data:
            return name in self.data
        return False


# Helper class that'll load up our specific values
class StaticConf:
    def __init__(self):
        config = Configuration()

        self.ip = config.get('ip')
        self.port = config.get('port', 10000)
        self.unsecure_nick_name = config.get('unsecure_nick_name', 'unknown')
        self.LISTEN_READ_BYTES = int(config.get('LISTEN_READ_BYTES', 10000))
        self.MAX_SIMULTANIOUS_CONNECTIONS = int(config.get('MAX_SIMULTANEOUS_CONNECTIONS', 5))
        self.listen_timeout = int(config.get('LISTEN_TIMEOUT_SECONDS', 5))
        self.MAX_STORAGE_SPACE_OTHER = int(config.get('MAX_STORAGE_SPACE_OTHER_MB', 50 * 1024) * 1024 * 1024)
        self.SWICHAROO_POLICY = config.get('SWICHAROO_POLICY', 'GRANT_ALL')
        self.SWICHAROO_MINSIZE_ACCEPT_ALL = int(config.get('SWICHAROO_MINSIZE_ACCEPT_ALL', 65536))
        self.SWICHAROO_FILE_MAXSIZE = int(config.get('SWICHAROO_FILE_MAXSIZE_KB', 32768) * 1024)
